Documentation
¶
Index ¶
- func Check(a, b interface{}) ([]string, error)
- func Convert(x interface{}) ([]float64, []string, []int, time.Time)
- func ECItoLookAngles(eci Vector, obs LLA, t time.Time) (az, rg, el float64)
- func Gmst(t time.Time) float64
- func JDay(t time.Time) float64
- func OMMinit(o *OMM) *satrec
- func TLEinit(tle1, tle2 string) *satrec
- type Grav
- type LLA
- type OMM
- type Vector
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ECItoLookAngles ¶
Calculate look angles for given satellite position in ECI and observer position in lat, long (deg, decimal deg) and alt
in meters. Returns azmuth in degrees, range in km, and elevation in degrees.
Reference https://celestrak.com/columns/v02n02/
Types ¶
type OMM ¶
type OMM struct {
NORAD_CAT_ID string // satnum
EPOCH string // epoch
MEAN_MOTION_DOT float64 // ndot
MEAN_MOTION_DDOT float64 // nddot
BSTAR float64 // bstar
INCLINATION float64 // inclo
RA_OF_ASC_NODE float64 // nodeo
ECCENTRICITY float64 // ecco
ARG_OF_PERICENTER float64 // argpo
MEAN_ANOMALY float64 // mo
MEAN_MOTION float64 // no
}
Click to show internal directories.
Click to hide internal directories.